#!/usr/bin/env python
# -*- coding: utf-8 -*-
# Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
# Copyright (C) 2008-2023 German Aerospace Center (DLR) and others.
# This program and the accompanying materials are made available under the
# terms of the Eclipse Public License 2.0 which is available at
# https://www.eclipse.org/legal/epl-2.0/
# This Source Code may also be made available under the following Secondary
# Licenses when the conditions for such availability set forth in the Eclipse
# Public License 2.0 are satisfied: GNU General Public License, version 2
# or later which is available at
# https://www.gnu.org/licenses/old-licenses/gpl-2.0-standalone.html
# SPDX-License-Identifier: EPL-2.0 OR GPL-2.0-or-later

# @file    runner.py
# @author  Michael Behrisch
# @author  Jakob Erdmann
# @author  Daniel Krajzewicz
# @date    2011-03-04


from __future__ import print_function
from __future__ import absolute_import
import os
import sys
if "SUMO_HOME" in os.environ:
    sys.path.append(os.path.join(os.environ['SUMO_HOME'], 'tools'))
import traci  # noqa
import sumolib  # noqa
import simpla  # noqa
from simpla import SimplaException  # noqa

binary = 'sumo-gui'
if 'nogui' in sys.argv:
    binary = 'sumo'

traci.start([sumolib.checkBinary(binary),
             '-c', 'sumo.sumocfg',
             '--step-length', '0.5',
             '--fcd-output', 'fcd.xml',
             '--fcd-output.max-leader-distance', '100'])

simpla.load("simpla.cfg.xml")

while traci.simulation.getMinExpectedNumber() > 0:
    edge_speed = traci.edge.getLastStepMeanSpeed("A0right0")
    #edge_speed_two = traci.edge.getLastStepMeanSpeed("A0right0")
    vehicle_count = traci.vehicle.getIDCount()
    vehicleIDs = traci.vehicle.getIDList()
    
    nPlatoon = 0
    sizePlatoon = 1
    for veh_id in vehicleIDs:
        veh_type = traci.vehicle.getTypeID(veh_id)
        veh_route = traci.vehicle.getRouteID(veh_id)
       # veh_new = traci.vehicle.add('435353643465v',veh_route)  

        if 't_leader' in veh_type:
            #veh_new = traci.vehicle.add("car",veh_route)
            #print(f'Found a platoon leader...')
            nPlatoon += 1
          
            if 't_follower' in veh_type:
                sizePlatoon += 1
        print(f'VEHICLE ROUTE ID IS:{veh_route}')
    
    for veh_id_new in vehicleIDs:
        veh_type = traci.vehicle.getTypeID(veh_id)
        veh_route = traci.vehicle.getRouteID(veh_id)
       
    print(f'Total Platoon at this time step: {nPlatoon}')
    print(f'Platoon Size at this time step: {sizePlatoon}')
    #traci.vehicle.add('taxiV%i' , '!v')
    #try:
     #   traci.vehicle.remove("v.0")
    #except TraCIException:
    #    pass
    #y = traci.vehicle.getRouteID(vehicleIDs)
    #print(f'Route ID{y}')

    #vehicle_type = traci.vehicle.getVehicleClass("car")
    #if vehicle_type == "car":
    #    print("I am a car!!!")

    lane_1 = traci.lane.getLastStepMeanSpeed("A0right0_0")

    print(f"Avg Speed: {edge_speed}, lane info: {lane_1}, Number of Cars (Traffic Density):{vehicle_count}, Vehicle List: {vehicleIDs}")
    num_plat = 0
    size_plat = 0                       
    traci.simulationStep()

traci.close()
